i18n

package
v0.0.0-...-01c5ac2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 11, 2026 License: GPL-3.0 Imports: 0 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	G  = GDefault
	NG = NGDefault
)

The following public i18n function variables define the internationalisation marker API available. An implementation specific version can be provided by the application or alternatively if left unmodified the default functions will by used (translation disabled).

Functions

func GDefault

func GDefault(msgid string) string

GDefault is the fallback implementation. This will simply return the provided string untranslated.

func NGDefault

func NGDefault(msgid string, msgidPlural string, n int) string

NGDefault is the fallback implementation. This will simply return the provided singular or plural string (depending on 'n') untranslated.

Types

This section is empty.

Jump to